@@ -181,10 +181,8 @@ checkpcmark(void)
     if (curwin->w_prev_pcmark.lnum != 0
 	    && (EQUAL_POS(curwin->w_pcmark, curwin->w_cursor)
 		|| curwin->w_pcmark.lnum == 0))
-    {
 	curwin->w_pcmark = curwin->w_prev_pcmark;
-	curwin->w_prev_pcmark.lnum = 0;		// Show it has been checked
-    }
+    curwin->w_prev_pcmark.lnum = 0;		// it has been checked
 }
 
 #if defined(FEAT_JUMPLIST) || defined(PROTO)
